@@ -48,8 +48,10 @@ makeHeatMap <- function(df, xTicksNum = 10, maxLabels = Inf){
 
 #' Visualization functions (raw signal, fragility matrix)
 #'
-#' @description `plotFragHeatmap`: plot fragility heatmaps with electrodes marked as soz colored
+#' @description `plot`: plot fragility heatmaps with electrodes marked as soz colored
 #'
+#' @param x Fragility object from \code{calcAdjFrag}
+#' @param y Not used (for S4 method compatibility)
 #' @param frag Fragility object from \code{calcAdjFrag}
 #' @param x.lab.size Numeric. Size of x-axis labels. Default is 4.
 #' @param y.lab.size Numeric. Size of y-axis labels. Default is 10
@@ -69,24 +71,23 @@ makeHeatMap <- function(df, xTicksNum = 10, maxLabels = Inf){
 #' data("pt01Frag")
 #' 
 #' ## plot the fragility heatmap
-#' plotFragHeatmap(frag = pt01Frag, groupIndex = sozNames)
+#' plot(pt01Frag, groupIndex = sozNames)
 #' 
-#' @rdname plotFragHeatmap
+#' @rdname plotFrag
 #' @export
-plotFragHeatmap <- function(
-    frag,
+setMethod("plot", signature(x = "Fragility", y = "missing"), 
+    function(x, y, 
     groupIndex = NULL,
     maxLabels = 50,
-    ranked=FALSE,
-    x.lab.size = 4,
+    ranked = FALSE,
+    x.lab.size = 10,
     y.lab.size = 10) {
-    stopifnot(is(frag, "Fragility"))
-    fragMat <- .ifelse(ranked, frag$frag_ranked, frag$frag)
+    fragMat <- .ifelse(ranked, x$frag_ranked, x$frag)
 
     elecNum <- nrow(fragMat)
     windowNum <- ncol(fragMat)
 
-    elecNames <- frag$electrodes
+    elecNames <- x$electrodes
     groupIndex <- checkIndex(groupIndex, elecNames)
 
     group1 <- groupIndex
@@ -95,7 +96,7 @@ plotFragHeatmap <- function(
     elecColor <- rep("blue", elecNum)
     elecColor[seq_along(group2)] <- "black"
 
-    startTime <- frag$startTimes
+    startTime <- x$startTimes
     if (is.null(startTime)) {
         xlabel <- "Time Index"
         stimes <- seq_len(windowNum)
@@ -104,7 +105,7 @@ plotFragHeatmap <- function(
         stimes <- startTime
     }
 
-    rownames(fragMat) <- frag$electrodes
+    rownames(fragMat) <- x$electrodes
     colnames(fragMat) <- stimes
 
     ## prepare the data.frame for visualization
@@ -112,22 +113,25 @@ plotFragHeatmap <- function(
     df <- as.data.frame(fragMat[allIndex, ])
 
     makeHeatMap(df, maxLabels = maxLabels) +
-        labs(x = xlabel, y = "Electrode", size = x.lab.size) +
+        labs(x = xlabel, y = "Electrode") +
         theme(
+            axis.text.x = element_text(size = x.lab.size), 
             axis.text.y = element_markdown(size = y.lab.size, colour = elecColor), # Adjust depending on electrodes
         )
 }
-
+)
 
 #' @description `plotFragQuantile`: Plot Fragility time quantiles for two electrodes groups
 #' 
-#' @rdname plotFragHeatmap
+#' @rdname plotFrag
 #' @examples
 #' ## plot the fragility quantiles
 #' plotFragQuantile(frag = pt01Frag, groupIndex = sozNames)
 #' 
 #' @export
-plotFragQuantile <- function(frag, groupIndex = NULL, groupName = "SOZ") {
+plotFragQuantile <- function(frag, groupIndex = NULL, groupName = "SOZ",
+    x.lab.size = 10,
+    y.lab.size = 10) {
     if (is.null(groupIndex)) {
         groupIndex <- estimateSOZ(frag)
     }
@@ -153,9 +157,10 @@ plotFragQuantile <- function(frag, groupIndex = NULL, groupName = "SOZ") {
     colnames(qmatrix) <- timeTicks
 
     makeHeatMap(qmatrix)+
-        labs(x = xlabel, y = "Quantiles", size = 8) +
+        labs(x = xlabel, y = "Quantiles") +
         theme(
-            axis.text.y = element_text(size = 8), # Adjust depending on electrodes
+            axis.text.y = element_text(size = y.lab.size), 
+            axis.text.x = element_text(size = x.lab.size)
         )
 }
 
@@ -163,7 +168,7 @@ plotFragQuantile <- function(frag, groupIndex = NULL, groupName = "SOZ") {
 #' @description `plotFragQuantile`: Plot Fragility time distribution for two electrodes groups
 #' @param bandType Character. The type of band to use, either "SEM" or "SD". Default is "SEM".
 #' @param rollingWindow Integer. Window size for rolling average smoothing. Default is 1 (no smoothing).
-#' @rdname plotFragHeatmap
+#' @rdname plotFrag
 #' @examples
 #' ## plot the fragility distribution
 #' plotFragDistribution(frag = pt01Frag, groupIndex = sozNames)
@@ -175,7 +180,9 @@ plotFragQuantile <- function(frag, groupIndex = NULL, groupName = "SOZ") {
 plotFragDistribution <- function(
     frag, groupIndex = NULL, 
     groupName="SOZ", bandType = c("SEM", "SD"), 
-    rollingWindow = 1, ranked=FALSE) {
+    rollingWindow = 1, ranked=FALSE,
+    x.lab.size = 10,
+    y.lab.size = 10) {
     bandType <- match.arg(bandType)
     if (is.null(groupIndex)) {
         groupIndex <- estimateSOZ(frag)
@@ -233,7 +240,7 @@ plotFragDistribution <- function(
     )
     
     groupColor <- glue("{groupName} +/- {bandType}")
-    refColor <- glue("{groupName}C +/- {bandType}")
+    refColor <- glue("REF +/- {bandType}")
     colors <- setNames(c("red", "black"), c(groupColor, refColor))
 
     ggplot(plotData, aes(x = .data$timeTicks)) +
@@ -249,5 +256,10 @@ plotFragDistribution <- function(
         geom_line(aes(y = .data$refLowerBound), color = "black", linetype = "blank") +
         geom_ribbon(aes(ymin = .data$groupLowerBound, ymax = .data$groupUpperBound), fill = "red", alpha = 0.5) +
         geom_ribbon(aes(ymin = .data$refLowerBound, ymax = .data$refUpperBound), fill = "black", alpha = 0.5) +
-        scale_color_manual(name = "Electrode groups", values = c(colors))
+        scale_color_manual(name = "Electrode groups", values = c(colors))+
+        theme(
+            axis.text.y = element_text(size = y.lab.size), 
+            axis.text.x = element_text(size = x.lab.size)
+        )
+
 }
